import bb.cascades 1.0

Page {
    id: cropScreen
    property double scaleFactor: 1.0
    property string imageSourceURL: ""
    property real curScaleRatio: 1.0
    property real initialScale: 1.0
    property real curAngleZ: 0
    property bool isPinching: false
    property real cropWidth
    property real cropHeight
    property real startCropX
    property real startCropY
    property int curImageWidth
    property int curImageHeight
    Container {
        layout: DockLayout {
        }

        ImageView {
            imageSource: "asset:///images/1.png"
            scalingMethod: ScalingMethod.AspectFill
        }
        ScrollView {
            id: scrollImageView
            preferredWidth: 720
            preferredHeight: 720
            horizontalAlignment: HorizontalAlignment.Center
            verticalAlignment: VerticalAlignment.Top
            scrollViewProperties.pinchToZoomEnabled: false
            
            ImageView {
                id: imageViewerCrop
                objectName: "imageViewerCrop"
                scalingMethod: ScalingMethod.AspectFit
                scaleX: curScaleRatio
                scaleY: curScaleRatio
            }
        }
        
        ImageView {
            id: cropRect
            property real dy: 0
            property real dx: 0
            property real prevX: 0
            property real prevY: 0
            imageSource: "asset:///images/cropFrame.png"
            scalingMethod: ScalingMethod.AspectFit
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Top
            onTouch: {
                if (isPinching) {
                    return;
                }
                // Disabling the implicit animations on the beard, this will make the small movements more snappy.
                //translationControllerX.enabled = false;

                // Checking for a press, then set the state variables we need.
                if (event.isDown()) {
                    cropRect.dx = event.windowX;
                    cropRect.dy = event.windowY;
                    console.log(dx + "x" + dy);
                } else if (event.isMove()) {
                    imageViewerCrop.translationX = cropRect.prevX + (event.windowX - dx);
                    imageViewerCrop.translationY = cropRect.prevY + (event.windowY - dy);
                    //console.log("Moving: " + imageViewerCrop.translationX + " | " + imageViewerCrop.translationY);
                } else if (event.isUp()) {
                    cropRect.prevX = imageViewerCrop.translationX;
                    cropRect.prevY = imageViewerCrop.translationY;
                    //console.log("Ended: " + imageViewerCrop.translationX + " | " + imageViewerCrop.translationY);
                }
            }
            gestureHandlers: [

                // Add a handler for pinch gestures
                PinchHandler {
                    // When the pinch gesture starts, save the initial scale of
                    // the image
                    onPinchStarted: {
                        isPinching = ! isPinching;
                        initialScale = imageViewerCrop.scaleX;
                    }

                    onPinchUpdated: {
                        curScaleRatio = initialScale + ((event.pinchRatio - 1) * scaleFactor);
                    }
                    onPinchEnded: {
                        if (imageViewerCrop.scaleX < 0.5) {
                            curScaleRatio = 0.5;
                        }
                        isPinching = ! isPinching;
                        console.log("curScaleRatio: " + curScaleRatio);
                    }
                }
            ]
        }
        
        Container {
            topPadding: 25
            leftPadding: 25
            rightPadding: 25
            verticalAlignment: VerticalAlignment.Top
            horizontalAlignment: HorizontalAlignment.Fill
            
            // Width Control
            Container {
                layout: DockLayout {
                }
                bottomMargin: 20
                horizontalAlignment: HorizontalAlignment.Fill
                verticalAlignment: VerticalAlignment.Center
                Container {
                    leftPadding: 30
                    rightPadding: 30
                    layout: StackLayout {
                        orientation: LayoutOrientation.LeftToRight
                    }
                    verticalAlignment: VerticalAlignment.Center
                    Label {
                        text: "Width"
                        minWidth: 90
                        verticalAlignment: VerticalAlignment.Center
                        textStyle {
                            fontSizeValue: 6
                            fontSize: FontSize.PointValue
                            color: Color.create("#FAFAFA")
                        }

                    }
                    Slider {
                        id: cropWidthControl
                        fromValue: 240
                        toValue: 720
                        value: 720
                        verticalAlignment: VerticalAlignment.Center
                        horizontalAlignment: HorizontalAlignment.Center
                        onValueChanged: {
                            cropRect.scaleX = cropWidthControl.value / 720;
                        }
                    }
                }
            }
        }
        Container {
            id: cropRectControl
            leftPadding: 25
            rightPadding: 25
            bottomPadding: 25
            verticalAlignment: VerticalAlignment.Bottom
            horizontalAlignment: HorizontalAlignment.Fill
            
            Container {
                horizontalAlignment: HorizontalAlignment.Center
                bottomMargin: 10
                layout: StackLayout {
                    orientation: LayoutOrientation.LeftToRight
                }
                
                ImageButton {
                    rightMargin: 50
                    visible: false
                    defaultImageSource: "asset:///images/icons/ic_edit_profile.png"
                    onClicked: {
                        _app.cropAndSetBBMAvatar720(imageSourceURL, curScaleRatio, imageViewerCrop.translationX, imageViewerCrop.translationY, cropRect.scaleX, cropRect.scaleY);
                        restoreDefault();
                    }
                }
                ImageButton {
                		defaultImageSource: "asset:///images/icons/ic_cancel.png"
                    rightMargin: 50
                    onClicked: {
                        restoreDefault();
                    }
                }
                ImageButton {
                    defaultImageSource: "asset:///images/icons/crop_icon.png"
                    scaleX: 1.1
                    scaleY: 1.1
                    onClicked: {
                        _app.cropIt720(imageSourceURL, curScaleRatio, imageViewerCrop.translationX, imageViewerCrop.translationY, cropRect.scaleX, cropRect.scaleY);
                        restoreDefault();
                    }
                }
            }
            // Height control
            Container {
                
                layout: DockLayout {

                }
                horizontalAlignment: HorizontalAlignment.Fill
                verticalAlignment: VerticalAlignment.Center
                Container {
                    layout: StackLayout {
                        orientation: LayoutOrientation.LeftToRight
                    }
                    leftPadding: 10
                    rightPadding: 10
                    verticalAlignment: VerticalAlignment.Center
                    horizontalAlignment: HorizontalAlignment.Fill
                    Label {
                        text: "Height"

                        minWidth: 90
                        verticalAlignment: VerticalAlignment.Center
                        textStyle {
                            fontSize: FontSize.PointValue
                            fontSizeValue: 6
                            color: Color.create("#FAFAFA")
                        }
                    }
                    Slider {
                        id: cropHeightControl
                        fromValue: 240
                        toValue: 720
                        value: 720
                        verticalAlignment: VerticalAlignment.Center
                        horizontalAlignment: HorizontalAlignment.Fill
                        onValueChanged: {
                            cropRect.scaleY = cropHeightControl.value / 720;
                        }
                    }
                }
            }
        }
    }
    /*
    actions: [
        ActionItem {
            title: "Crop"
            ActionBar.placement: ActionBarPlacement.OnBar
            imageSource: "asset:///images/icons/crop_icon.png"
            onTriggered: {
                _app.cropIt(imageSourceURL, curScaleRatio, imageViewerCrop.translationX, imageViewerCrop.translationY, cropRect.scaleX, cropRect.scaleY);
                restoreDefault();
            }
        },
        ActionItem {
            title: "BBM Avatar"
            imageSource: "asset:///images/icons/ic_edit_profile.png"
            ActionBar.placement: ActionBarPlacement.OnBar
            onTriggered: {
                _app.cropAndSetBBMAvatar(imageSourceURL, curScaleRatio, imageViewerCrop.translationX, imageViewerCrop.translationY, cropRect.scaleX, cropRect.scaleY);
                restoreDefault();
            }
        },
        ActionItem {
            title: "Cancel"
            ActionBar.placement: ActionBarPlacement.OnBar
            imageSource: "asset:///images/icons/ic_cancel.png"
            onTriggered: {
                restoreDefault();
            }
        }
    ]
    */
    function restoreDefault() {
        cropWidthControl.value = 720;
        cropHeightControl.value = 720;
        curScaleRatio = 1.0;
        initialScale = 1.0;
        curAngleZ = 0;
        cropRect.dx = 0;
        cropRect.dy = 0;
        cropRect.prevX = 0;
        cropRect.prevY = 0;
        imageViewerCrop.translationX = 0;
        imageViewerCrop.translationY = 0;
        cropScreenSheet.close();
    }
}
