import bb.cascades 1.0

Page {
    //First Time
    property bool isFirstTime: false

    // Location
    property string locationText
    property variant curLat: 10.79254237
    property variant curLong: 106.70135121
    property bool instaxReady: false
    property bool isStamped: false

    // Time
    property variant today

    // Image info
    property string imageSourceURL: ""
    property string imageNameString: "Image File Name"
    property string mimetype: ""
    property int curWidth
    property int curHeight
    property double curScaleX: 1.0
    property double curScaleY: 1.0
    property double initialScale
    property double scaleFactor: 0.8
    property int curAngleZ: 0
    property variant imageData

    // Save
    property bool isDirty: false

    // Other
    property bool zoomIn: false
    property bool isMirrored: false
    property bool startLoadingIndicator: false
    property bool utilitiesIsShown: false

    // Genric Info on Top:
    property bool imageNameShown: false

    // Locating Light Control
    property bool lightControlShown: false
    property int lightControlHideY: -440
    property int lightControlShowY: 0

    // Filter Bar
    property bool filterIsShown: false
    property bool disableAniImage: false

    // Facebook
    property alias shareToFBActionItemTitle: shareToFBActionItem.title

    // Main Container
    Container {
        background: Color.create("#000000")
        layout: DockLayout {
        }
        ImageView {
            imageSource: "asset:///images/1.png"
            scalingMethod: ScalingMethod.AspectFill
        }

        Container {
            layout: DockLayout {
            }

            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Fill
            ImageView {
                id: imageViewer
                objectName: "imageViewer"
                scalingMethod: ScalingMethod.AspectFit
                horizontalAlignment: HorizontalAlignment.Center
                verticalAlignment: VerticalAlignment.Center
                scaleX: curScaleX
                scaleY: curScaleY
                onImageChanged: {
                    if (! disableAniImage) {
                        restoreOriginalEffect.play();
                    } else {
                        disableAniImage = ! disableAniImage;
                    }
                }
                contextActions: [
                    ActionSet {
                        title: "Context Menu"
                        // Facebook
                        ActionItem {
                            id: shareToFBActionItem
                            imageSource: "asset:///images/icons/fb.png"
                            title: "Share | Facebook"
                            onTriggered: {
                                if (_app.isLoginFacebook()) {
                                    _app.preparePhotoForFBUploadScreen();
                                    fbSheet.open();
                                    fbSheetPage.requestFocusOnTextArea();
                                } else {
                                    _app.loginFB();
                                }
                            }
                        }
                        InvokeActionItem {
                            query {
                                uri: "file:///accounts/1000/shared/photos/temp_shared_photo.jpg"
                            }
                        }
                        DeleteActionItem {
                            onTriggered: {
                                _app.deleteImage(imageSourceURL);
                                closeImageScreen();
                            }
                        }
                    }
                ]
                animations: [
                    RotateTransition {
                        id: rotateImageViewer
                        fromAngleZ: imageViewer.rotationZ
                        toAngleZ: curAngleZ
                        duration: 1000
                        easingCurve: StockCurve.CubicOut
                        property bool isPlaying: false
                        onStarted: {
                            isPlaying = ! isPlaying;
                        }
                        onEnded: {
                            imageViewer.rotationZ = curAngleZ;
                            _app.transformRotate(curAngleZ);
                            isPlaying = ! isPlaying;
                        }
                    },
                    ScaleTransition {
                        id: zoomInImageViewer
                        toX: 2.0
                        toY: 2.0
                        duration: 600
                        onEnded: {
                            curScaleX = 2.0;
                            curScaleY = 2.0;
                            // And update the curImage state:
                            //_app.transformScale(imageViewer.scaleX, imageViewer.scaleY);
                        }
                    },
                    ScaleTransition {
                        id: zoomOutImageViewer
                        toX: 1.0
                        toY: 1.0
                        duration: 600
                        onEnded: {
                            curScaleX = 1.0;
                            curScaleY = 1.0;
                            // And update the curImage state:
                            //_app.transformScale(imageViewer.scaleX, imageViewer.scaleY);
                        }
                    },
                    ScaleTransition {
                        id: scaleToZeroY
                        duration: 600
                        toY: 0.0
                        onEnded: {
                            _app.mirrorImage(false, true);
                            scaleToOriginalY.play();
                        }
                    },
                    ScaleTransition {
                        id: scaleToOriginalY
                        duration: 600
                        toY: curScaleY
                        toX: curScaleX
                    },
                    ScaleTransition {
                        id: scaleToZeroX
                        duration: 600
                        toX: 0.0
                        onEnded: {
                            _app.mirrorImage(true, false);
                            scaleToOriginalX.play();
                        }
                    },
                    ScaleTransition {
                        id: scaleToOriginalX
                        duration: 600
                        toX: curScaleX
                        toY: curScaleY
                    },
                    ScaleTransition {
                        id: restoreOriginalEffect
                        fromX: 0.9
                        fromY: 0.9
                        toX: 1
                        toY: 1
                        duration: 600
                        easingCurve: StockCurve.ElasticInOut
                    }
                ]
            }
            gestureHandlers: [

                // Add a handler for pinch gestures
                PinchHandler {
                    // When the pinch gesture starts, save the initial scale of
                    // the image
                    onPinchStarted: {
                        initialScale = imageViewer.scaleX;
                    }

                    // As the pinch expands or contracts, change the scale of the
                    // image
                    onPinchUpdated: {
                        curScaleX = initialScale + ((event.pinchRatio - 1) * scaleFactor);
                        curScaleY = initialScale + ((event.pinchRatio - 1) * scaleFactor);
                        imageViewer.rotationZ = curAngleZ + event.rotation; // Should rotate from curAngleZ to new rotation returned by pinchUpdate
                    }
                    onPinchEnded: {
                        curAngleZ = imageViewer.rotationZ; // Sync curAngleZ with rotationZ after pinch ended.
                        if (imageViewer.scaleX < 1.0) {
                            curScaleX = 1.0;
                            curScaleY = 1.0;
                        }
                    }
                },
                DoubleTapHandler {
                    onDoubleTapped: {
                        console.log("DoubleTap at position " + event.x + ", " + event.y)
                        if (imageViewer.scaleX < 2.0) {
                            zoomInImageViewer.play();
                        } else {
                            zoomOutImageViewer.play();
                        }
                    }
                },
                TapHandler {
                    onTapped: {
                        if (filterIsShown) {
                            filterIsShown = false;
                            filterList.translationY = 350;
                        }
                        if (utilitiesIsShown) {
                            utilitiesIsShown = false;
                            utilBar.translationY = 270;
                        }
                        if (topToolsBar.translationY == 0) {
                            //console.log("Top Tool Bar is shown. We hide it now.");
                            hideTopToolBar();
                        } else {
                            //console.log("Top Tool Bar is hidden. We show it now.");
                            showTopToolBar();
                        }
                    }
                }
            ]
        }
        

        // Brightness/Contrast Container
        Container {
            id: lightControl
            //opacity: 0.8
            translationY: lightControlHideY
            layout: DockLayout {

            }
            rightPadding: 20
            leftPadding: 20
            onTranslationYChanged: {
                if (translationY == lightControlShowY) {
                    hideTopToolBar();
                } else {
                    showTopToolBar();
                }
            }
            Container {
                topPadding: 10
                layout: StackLayout {
                    orientation: LayoutOrientation.TopToBottom
                }

                // Brightness Control
                Container {
                    layout: DockLayout {

                    }
                    horizontalAlignment: HorizontalAlignment.Fill
                    verticalAlignment: VerticalAlignment.Center
                    //background: Color.Black
                    topPadding: 5
                    leftPadding: 5
                    rightPadding: 5
                    bottomPadding: 5
                    ImageView {
                        imageSource: "asset:///images/backgrounds/RoundedRectangle_Boder.png"
                    }
                    Container {
                        layout: StackLayout {
                            orientation: LayoutOrientation.LeftToRight
                        }
                        preferredHeight: 91
                        rightPadding: 20
                        horizontalAlignment: HorizontalAlignment.Fill
                        verticalAlignment: VerticalAlignment.Center
                        //background: Color.create("#373737")
                        ImageView {
                            imageSource: "asset:///images/icons/brightness-.png"
                            layoutProperties: StackLayoutProperties {
                                spaceQuota: 1
                            }
                            horizontalAlignment: HorizontalAlignment.Center
                            verticalAlignment: VerticalAlignment.Center
                            scalingMethod: ScalingMethod.AspectFit
                        }
                        Slider {
                            id: brightnessSlider
                            fromValue: 0
                            toValue: 100
                            value: 50
                            layoutProperties: StackLayoutProperties {
                                spaceQuota: 8
                            }
                            horizontalAlignment: HorizontalAlignment.Fill
                            verticalAlignment: VerticalAlignment.Center
                            onValueChanged: {
                                if (lightControlShown) {
                                    _app.changeBrightness(brightnessSlider.value - 50);
                                }
                            }
                        }
                        ImageView {
                            imageSource: "asset:///images/icons/brightness+.png"
                            layoutProperties: StackLayoutProperties {
                                spaceQuota: 1
                            }
                            horizontalAlignment: HorizontalAlignment.Center
                            verticalAlignment: VerticalAlignment.Center
                            scalingMethod: ScalingMethod.AspectFit
                        }
                    }
                }

                // Contrast Control
                Container {
                    layout: DockLayout {

                    }
                    horizontalAlignment: HorizontalAlignment.Fill
                    verticalAlignment: VerticalAlignment.Center
                    //background: Color.Black
                    topPadding: 5
                    leftPadding: 5
                    rightPadding: 5
                    bottomPadding: 5
                    ImageView {
                        imageSource: "asset:///images/backgrounds/RoundedRectangle_Boder.png"
                    }
                    Container {
                        layout: StackLayout {
                            orientation: LayoutOrientation.LeftToRight
                        }
                        preferredHeight: 91
                        rightPadding: 20
                        horizontalAlignment: HorizontalAlignment.Fill
                        verticalAlignment: VerticalAlignment.Center
                        //background: Color.create("#373737")
                        ImageView {
                            imageSource: "asset:///images/icons/contrast-.png"
                            layoutProperties: StackLayoutProperties {
                                spaceQuota: 1
                            }
                            horizontalAlignment: HorizontalAlignment.Center
                            verticalAlignment: VerticalAlignment.Center
                            scalingMethod: ScalingMethod.AspectFit
                        }
                        Slider {
                            id: contrastSlider
                            fromValue: 0
                            toValue: 20
                            value: 0
                            layoutProperties: StackLayoutProperties {
                                spaceQuota: 8
                            }
                            horizontalAlignment: HorizontalAlignment.Fill
                            verticalAlignment: VerticalAlignment.Center
                            onValueChanged: {
                                if (lightControlShown) {
                                    _app.changeContrast(contrastSlider.value);
                                }
                            }
                        }
                        ImageView {
                            imageSource: "asset:///images/icons/contrast+.png"
                            layoutProperties: StackLayoutProperties {
                                spaceQuota: 1
                            }
                            horizontalAlignment: HorizontalAlignment.Center
                            verticalAlignment: VerticalAlignment.Center
                            scalingMethod: ScalingMethod.AspectFit
                        }
                    }
                }
                // Button Control
                Container {
                    layout: StackLayout {
                        orientation: LayoutOrientation.LeftToRight
                    }
                    horizontalAlignment: HorizontalAlignment.Right
                    topPadding: 10
                    bottomPadding: 10
                    leftPadding: 10
                    //rightPadding: 10
                    Button {
                        imageSource: "asset:///images/icons/ic_cancel.png"
                        preferredWidth: 81
                        onClicked: {
                            //toggleImageName();
                            toggleLightControlBar();
                            brightnessSlider.value = 50;
                            contrastSlider.value = 0;
                            //_app.restoreOriginalImage();
                            _app.cancelAdjustLight();
                        }
                    }
                    Button {
                        preferredWidth: 81
                        imageSource: "asset:///images/icons/ic_done.png"
                        onClicked: {
                            isDirty = true;
                            _app.applyAdjustLight();
                            //toggleImageName();
                            toggleLightControlBar();
                            brightnessSlider.value = 50;
                            contrastSlider.value = 0;
                        }
                    }
                }

            }
            animations: [
                TranslateTransition {
                    id: showLightControl
                    toY: lightControlShowY
                    duration: 500
                },
                TranslateTransition {
                    id: hideLightControl
                    toY: lightControlHideY
                    duration: 500
                }
            ]
        }
        // Top Tools Bar
        Container {
            id: topToolsBar
            topPadding: 10
            bottomPadding: 0
            leftPadding: 0
            rightPadding: 0
            layout: StackLayout {
                orientation: LayoutOrientation.LeftToRight
            }
            PhotoUtilityButton {
                property string defaultImageURL: "asset:///images/icons/InstaX_circle.png"
                onIsClicked: {
                    if (instaxReady) {
                        locationSheet.open();
                    } else {
                        _app.showToastMessage("InstaX is not ready.");
                    }
                }
            }
            PhotoUtilityButton {
                property string defaultImageURL: "asset:///images/icons/set_wall_circle.png"
                onIsClicked: {
                    //setCurPhotoAsWallpaper();
                    confirmSetWallpaper.show();
                }
            }
            PhotoUtilityButton {
                property string defaultImageURL: "asset:///images/icons/reset_circle.png"
                onIsClicked: {
                    //restoreDefault();
                    confirmRestoreOriginal.show();
                }
            }
            PhotoUtilityButton {
                property string defaultImageURL: "asset:///images/icons/close_circle.png"
                onIsClicked: {
                    askBeforeClose();
                }
            }
        }
        // Utilities
        Container {
            id: utilBar
            translationY: 270
            horizontalAlignment: HorizontalAlignment.Center
            verticalAlignment: VerticalAlignment.Bottom
            //background: Color.create("#676767")
            topPadding: 20
            bottomPadding: 20
            Container {
                layout: StackLayout {
                    orientation: LayoutOrientation.LeftToRight
                }
                PhotoUtilityButton {
                    property string defaultImageURL: "asset:///images/icons/mirroredX.png"
                    onIsClicked: {
                        isDirty = true;
                        scaleToZeroX.play();
                    }
                }
                PhotoUtilityButton {
                    property string defaultImageURL: "asset:///images/icons/mirroredY.png"
                    onIsClicked: {
                        isDirty = true;
                        scaleToZeroY.play();
                    }
                }
                PhotoUtilityButton {
                    property string defaultImageURL: "asset:///images/icons/rotate_clockwise.png"
                    onIsClicked: {
                        if (! rotateImageViewer.isPlaying) {
                            isDirty = true;
                            curAngleZ = imageViewer.rotationZ + 90;
                            rotateImageViewer.play();
                        }
                    }
                }
                PhotoUtilityButton {
                    property string defaultImageURL: "asset:///images/icons/rotate_anticlockwise.png"
                    onIsClicked: {
                        if (! rotateImageViewer.isPlaying) {
                            isDirty = true;
                            curAngleZ = imageViewer.rotationZ - 90;
                            rotateImageViewer.play();
                        }
                    }
                }
            }
            Container {
                translationX: 34
                preferredWidth: 700
                preferredHeight: 1
                background: Color.create("#878787")
                topMargin: 30
                bottomMargin: 30
            }
            Container {
                layout: StackLayout {
                    orientation: LayoutOrientation.LeftToRight
                }
                /*
                 * PhotoUtilityButton {
                 * property string defaultImageURL: "asset:///images/icons/set_bbm_avatar.png"
                 * onIsClicked: {
                 * //_app.cropModeOn(imageSourceURL, true);
                 * //cropScreenSheet.open();
                 * _app.setAsBBMAvatar(imageSourceURL);
                 * }
                 * }*/
                PhotoUtilityButton {
                    property string defaultImageURL: "asset:///images/icons/pdf_circle.png"
                    onIsClicked: {
                        confirmExportPDFDialog.show();
                    }
                }
                PhotoUtilityButton {
                    property string defaultImageURL: "asset:///images/icons/crop.png"
                    onIsClicked: {
                        _app.cropModeOn(imageSourceURL, false);
                        cropScreenSheet.open();
                    }
                }
                PhotoUtilityButton {
                    property string defaultImageURL: "asset:///images/icons/resize.png"
                    onIsClicked: {
                        resizeContainer.show();
                    }
                }
                PhotoUtilityButton {
                    property string defaultImageURL: "asset:///images/icons/light_circle.png"
                    onIsClicked: {
                        _app.adjustLightMode();
                        toggleLightControlBar();
                    }
                }
            }
        }

        // Info + Brightness/contrast Container
        Container {
            layout: StackLayout {
                orientation: LayoutOrientation.TopToBottom
            }
            topPadding: 5
            leftPadding: 10
            bottomPadding: 5
            translationY: -225
            preferredHeight: 220
            background: Color.create("#404040")
            horizontalAlignment: HorizontalAlignment.Fill
            Container {
                layoutProperties: StackLayoutProperties {
                    spaceQuota: 1
                }
                Label {
                    id: imageName
                    objectName: "imageName"
                    text: imageNameString
                    textStyle {
                        color: Color.create("#FAFAFA")
                        fontSizeValue: 6
                    }
                    horizontalAlignment: HorizontalAlignment.Fill
                    verticalAlignment: VerticalAlignment.Center
                }
            }

            // Image Properties
            Container {
                layout: StackLayout {
                    orientation: LayoutOrientation.LeftToRight
                }
                layoutProperties: StackLayoutProperties {
                    spaceQuota: 1
                }
                Label {
                    id: imageSizeLabel
                    text: "Size: " + curWidth + "x" + curHeight
                    textStyle {
                        color: Color.create("#FAFAFA")
                        fontSize: FontSize.PointValue
                        fontSizeValue: 6
                    }
                    layoutProperties: StackLayoutProperties {
                        spaceQuota: 1
                    }
                    horizontalAlignment: HorizontalAlignment.Fill
                    verticalAlignment: VerticalAlignment.Center
                }
                Label {
                    id: imageScaleLabel
                    text: "Scaled: " + parseInt(curWidth * imageViewer.scaleX) + "x" + parseInt(curHeight * imageViewer.scaleY)
                    textStyle {
                        color: Color.create("#FAFAFA")
                        fontSize: FontSize.PointValue
                        fontSizeValue: 6
                    }
                    layoutProperties: StackLayoutProperties {
                        spaceQuota: 1
                    }
                    horizontalAlignment: HorizontalAlignment.Fill
                    verticalAlignment: VerticalAlignment.Center
                }
                Label {
                    id: imageRotateLabel
                    text: "R: " + parseInt(imageViewer.rotationZ) + "°"
                    textStyle {
                        color: Color.create("#FAFAFA")
                        fontSize: FontSize.PointValue
                        fontSizeValue: 6
                    }
                    layoutProperties: StackLayoutProperties {
                        spaceQuota: 1
                    }
                    horizontalAlignment: HorizontalAlignment.Fill
                    verticalAlignment: VerticalAlignment.Center
                }
            }
            animations: [
                TranslateTransition {
                    id: showImageName
                    toY: 0
                    duration: 400
                },
                TranslateTransition {
                    id: hideImageName
                    toY: -225
                    duration: 400
                }
            ]
        }
        Container {
            // Filter List.
            id: filterList
            verticalAlignment: VerticalAlignment.Bottom
            translationY: 350
            ScrollView {
                //horizontalAlignment: HorizontalAlignment.Fill
                preferredWidth: 1280
                scrollViewProperties {
                    scrollMode: ScrollMode.Horizontal
                    overScrollEffectMode: OverScrollEffectMode.OnScroll
                }

                Container {
                    layout: DockLayout {
                    }
                    leftPadding: 10
                    Container {
                        layout: StackLayout {
                            orientation: LayoutOrientation.LeftToRight
                        }
                        bottomPadding: 10

                        FilterContainer {
                            id: vintageFilter
                            filterName: "Vintage"
                            filterImageSrc: "asset:///images/filter_icons/vintage.png"
                            onApplyFilter: {
                                _app.applyVintage();
                            }
                        }
                        FilterContainer {
                            id: classicFilter
                            filterName: "Classic"
                            filterImageSrc: "asset:///images/filter_icons/classic.png"
                            onApplyFilter: {
                                _app.applyClassic();
                            }
                        }
                        FilterContainer {
                            id: crossFilter
                            filterName: "Cross"
                            filterImageSrc: "asset:///images/filter_icons/cross.png"
                            onApplyFilter: {
                                _app.applyCrossProcessing();
                            }
                        }
                        FilterContainer {
                            id: bwFilter
                            filterName: "B&W"
                            filterImageSrc: "asset:///images/filter_icons/bw.png"
                            onApplyFilter: {
                                //_app.greyScaleIt();
                                _app.applyBW();
                            }
                        }
                        FilterContainer {
                            id: sepiaFilter
                            filterName: "Sepia"
                            filterImageSrc: "asset:///images/filter_icons/sepia.png"
                            onApplyFilter: {
                                _app.applySepia();
                            }
                        }
                        FilterContainer {
                            id: vignetteFilter
                            filterName: "Vignette"
                            filterImageSrc: "asset:///images/filter_icons/vignette.png"
                            onApplyFilter: {
                                _app.applyVignette();
                            }
                        }
                        FilterContainer {
                            id: greyScaleFilter
                            filterName: "Greyscale"
                            filterImageSrc: "asset:///images/filter_icons/greyscale.png"
                            onApplyFilter: {
                                _app.greyScaleIt();
                            }
                        }
                        FilterContainer {
                            id: tiltShiftFilter
                            filterName: "Tilt&Sift"
                            filterImageSrc: "asset:///images/filter_icons/blur.png"
                            onApplyFilter: {
                                _app.applyTiltShift();
                            }
                        }
                        FilterContainer {
                            id: warmFilter
                            filterName: "Warm"
                            filterImageSrc: "asset:///images/filter_icons/warm.png"
                            onApplyFilter: {
                                _app.warmIt(20);
                            }
                        }
                        FilterContainer {
                            id: coolFilter
                            filterName: "Cool"
                            filterImageSrc: "asset:///images/filter_icons/cool.png"
                            onApplyFilter: {
                                _app.coolIt(30);
                            }
                        }
                        FilterContainer {
                            id: blurFilter
                            filterName: "Blur"
                            filterImageSrc: "asset:///images/filter_icons/blur.png"
                            onApplyFilter: {
                                _app.blurCurrentImage();
                            }
                        }
                    }
                }
            }

            // Grunge Effect Filters

            ScrollView {
                //horizontalAlignment: HorizontalAlignment.Fill
                preferredWidth: 1280
                scrollViewProperties {
                    scrollMode: ScrollMode.Horizontal
                    overScrollEffectMode: OverScrollEffectMode.OnScroll
                }

                Container {
                    layout: DockLayout {
                    }
                    leftPadding: 10
                    Container {
                        layout: StackLayout {
                            orientation: LayoutOrientation.LeftToRight
                        }
                        bottomPadding: 10
                        FilterContainer {
                            filterName: "Dirty 1"
                            filterImageSrc: "asset:///images/filter_icons/Frame1.png"
                            onApplyFilter: {
                                _app.applyOverlay("Dirty1");
                            }
                        }
                        FilterContainer {
                            filterName: "Dirty 2"
                            filterImageSrc: "asset:///images/filter_icons/Frame2.png"
                            onApplyFilter: {
                                _app.applyOverlay("Dirty2");
                            }
                        }
                        FilterContainer {
                            filterName: "Dirty 3"
                            filterImageSrc: "asset:///images/filter_icons/Frame3.png"
                            onApplyFilter: {
                                _app.applyOverlay("Dirty3");
                            }
                        }
                        FilterContainer {
                            filterName: "Dirty 4"
                            filterImageSrc: "asset:///images/filter_icons/Frame4.png"
                            onApplyFilter: {
                                _app.applyOverlay("Dirty4");
                            }
                        }
                        FilterContainer {
                            filterName: "Dirty 5"
                            filterImageSrc: "asset:///images/filter_icons/Frame5.png"
                            onApplyFilter: {
                                _app.applyOverlay("Dirty5");
                            }
                        }
                        FilterContainer {
                            filterName: "Dirty 6"
                            filterImageSrc: "asset:///images/filter_icons/Frame6.png"
                            onApplyFilter: {
                                _app.applyOverlay("Dirty6");
                            }
                        }
                        FilterContainer {
                            filterName: "Dirty 7"
                            filterImageSrc: "asset:///images/filter_icons/Frame7.png"
                            onApplyFilter: {
                                _app.applyOverlay("Dirty7");
                            }
                        }
                        FilterContainer {
                            filterName: "Dirty 8"
                            filterImageSrc: "asset:///images/filter_icons/Frame8.png"
                            onApplyFilter: {
                                _app.applyOverlay("Dirty8");
                            }
                        }
                        FilterContainer {
                            filterName: "Dirty 9"
                            filterImageSrc: "asset:///images/filter_icons/Frame9.png"
                            onApplyFilter: {
                                _app.applyOverlay("Dirty9");
                            }
                        }
                        FilterContainer {
                            filterName: "Dirty 10"
                            filterImageSrc: "asset:///images/filter_icons/Frame10.png"
                            onApplyFilter: {
                                _app.applyOverlay("Dirty10");
                            }
                        }
                    }
                }
            }
        }

        Resize {
            id: resizeContainer
            onResizeImage: {
                isDirty = true;
                _app.resizeImageFromUser(resizeOption, resizeTo);
            }
        }

        TweetPanel {
            id: tweetPanel
            onTweetButtonClicked: {
                startLoadingIndicator = true;
                _app.postStatus(tweetText + " --via Photo X Pro | http://goo.gl/eEb96", imageSourceURL);
            }
        }

        ActivityIndicator {
            id: loadingIndicator
            objectName: "loadingIndicator"
            visible: startLoadingIndicator
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Fill
            onVisibleChanged: {
                if (visible) {
                    loadingIndicator.start();
                } else {
                    loadingIndicator.stop();
                }
            }
        }

        ImageView {
            id: instructImage
            imageSource: "asset:///images/backgrounds/first_time_instruction.png"
            verticalAlignment: VerticalAlignment.Fill
            horizontalAlignment: HorizontalAlignment.Fill
            opacity: 0.8
            //visible: isFirstTime
            visible: false
            onTouch: {
                instructImage.visible = false;
            }
        }
    }
    actions: [
        ActionItem {
            title: "Effects"
            ActionBar.placement: ActionBarPlacement.OnBar
            imageSource: "asset:///images/icons/Effects.png"
            onTriggered: {
                toggleFiltersBar();
            }
        },
        ActionItem {
            title: "Tools"
            ActionBar.placement: ActionBarPlacement.OnBar
            imageSource: "asset:///images/icons/ic_edit.png"
            onTriggered: {
                toggleToolsBar();
            }
        },
        ActionItem {
            title: "Undo"
            ActionBar.placement: ActionBarPlacement.OnBar
            imageSource: "asset:///images/icons/previous.png"
            onTriggered: {
                _app.undoAction();
                if (isStamped) {
                    isStamped = false;
                }
            }
        },
        // Facebook
        ActionItem {
            imageSource: "asset:///images/icons/fb.png"
            title: shareToFBActionItem.title
            onTriggered: {
                if (_app.isLoginFacebook()) {
                    _app.preparePhotoForFBUploadScreen();
                    fbSheet.open();
                    fbSheetPage.requestFocusOnTextArea();
                } else {
                    _app.loginFB();
                }
            }
        },
        InvokeActionItem {
            id: shareInvokeActionItem
            objectName: "shareInvokeActionItem"
            query {
                uri: "file:///accounts/1000/shared/photos/temp_shared_photo.jpg"
            }
        },
        ActionItem {
            title: "Save"
            imageSource: "asset:///images/icons/save.png"
            onTriggered: {
                imageScreenPage.saveChanges();
            }
        },
        /*
         * ActionItem {
         * title: "Help"
         * imageSource: "asset:///images/icons/ic_help.png"
         * onTriggered: {
         * helpSheet.open();
         * }
         * },*/
        ActionItem {
            title: "Reset"
            imageSource: "asset:///images/icons/reset_circle_81.png"
            onTriggered: {
                settingsPageSheet.open();
            }
        },
        ActionItem {
            title: "Delete"
            imageSource: "asset:///images/icons/trash.png"
            onTriggered: {
                confirmDeleteDialog.show();
            }
        }
    ]
    attachedObjects: [

        // Alert Custom Dialog
        AlertDialog {
            id: alertDialog
            objectName: "alertDialog"
        },

        // Facebook Page
        Sheet {
            id: fbSheet
            FBPage {
                id: fbSheetPage
                onSharedToFB: {
                    startLoadingIndicator = true;
                    _app.uploadPictureToFB(imageSourceURL, statusText, squareIt);
                }
            }
        },

        // Facebook Authentication Page
        Sheet {
            id: fbAuthSheet
            objectName: "fbAuthSheet"
            FBAuthPage {
                id: fbAuthSheetPage
                objectName: "fbAuthSheetPage"
            }
        },

        // Crop
        Sheet {
            id: cropScreenSheet
            peekEnabled: false
            CropScreen {
                id: cropScreen
                objectName: "cropScreen"
            }
        },

        // Location List
        Sheet {
            id: locationSheet
            property bool isCancelled: false 
            Page {
                Container {
                    topPadding: 10
                    Label {
                        text: "Choose Closest Location"
                        horizontalAlignment: HorizontalAlignment.Center
                        verticalAlignment: VerticalAlignment.Center
                        textStyle {
                            color: Color.create("#CC3F10")
                            fontSize: FontSize.Large
                            fontStyle: FontStyle.Italic
                        }
                    }
                    Divider {

                    }
                    ListView {
                        id: locationListView
                        objectName: "locationListView"
                        //-- Override default GroupDataModel::itemType() behaviour, which is to return item type "header"
                        function itemType(data, indexPath) {
                            return "locationItem";
                        }
                        listItemComponents: [
                            ListItemComponent {
                                type: "locationItem"
                                Container {
                                    topPadding: 25
                                    leftPadding: 25
                                    rightPadding: 25
                                    bottomPadding: 25
                                    verticalAlignment: VerticalAlignment.Center
                                    horizontalAlignment: HorizontalAlignment.Fill
                                    Label {
                                        text: ListItemData
                                        multiline: true
                                        horizontalAlignment: HorizontalAlignment.Right
                                        verticalAlignment: VerticalAlignment.Center
                                        textStyle {
                                            color: Color.create("#96B800")
                                            fontSize: FontSize.Medium
                                            fontStyle: FontStyle.Italic
                                        }
                                    }
                                    Divider {

                                    }
                                }
                            }
                        ]
                        onTriggered: {
                            locationText = locationListView.dataModel.data(indexPath);
                            locationSheet.close();
                        }
                    }
                }
                actions: [
                    ActionItem {
                        title: "Cancel"
                        imageSource: "asset:///images/icons/ic_cancel.png"
                        ActionBar.placement: ActionBarPlacement.OnBar
                        onTriggered: {
                            locationSheet.isCancelled = true;
                            locationSheet.close();
                        }
                    }
                ]
            }
            onClosed: {
                if(!locationSheet.isCancelled){
                    skinSheet.open();
                } else {
                    locationSheet.isCancelled = !locationSheet.isCancelled;
                }
            }
        },
        Sheet {
            id: skinSheet
            property bool isCancelled: false 
            SkinScreen {
                id: skinScreen
            }
            onClosed: {
                if(!skinSheet.isCancelled){
                    _app.updateLocationText(locationText);
                    _app.applyLocation();
                } else {
                    skinSheet.isCancelled = !skinSheet.isCancelled;
                }
            }
        }
    ]
    onCreationCompleted: {
        refreshDate();
    }
    function exportToPDF() {
        _app.createPDF(imageSourceURL, settingsPage.pdfSizeA4);
    }
    function setCurPhotoAsWallpaper() {
        _app.setWallpaper(imageSourceURL);
    }
    function deleteCurPhoto() {
        _app.deleteImage(imageSourceURL);
        closeImageScreen();
    }
    function toggleFiltersBar() {
        if (filterIsShown) {
            filterList.translationY = 350;
        } else {
            if (utilitiesIsShown) {
                utilBar.translationY = 270;
                utilitiesIsShown = ! utilitiesIsShown;
            }
            filterList.translationY = 0;

			// Show Top Tools Bar
            showTopToolBar();
        }
        filterIsShown = ! filterIsShown;

    }
    function toggleToolsBar() {
        if (utilitiesIsShown) {
            utilBar.translationY = 270;
        } else {
            if (filterIsShown) {
                filterIsShown = ! filterIsShown;
                filterList.translationY = 350;
            }
            utilBar.translationY = 0;

            // Show Top Tools Bar
            showTopToolBar();
        }
        utilitiesIsShown = ! utilitiesIsShown;
    }
    function refreshDate() {
        today = new Date();
        var amPM = " AM ";
        var hours = today.getHours();
        if (hours > 12) {
            hours = hours - 12;
            amPM = " PM ";
            if (hours < 10) {
                hours = "0" + hours;
            }
        } else if (hours == 12) {
            amPM = " PM ";
        }
        var minutes = today.getMinutes();
        if (minutes < 10) {
            minutes = "0" + minutes;
        }
        var timeText = hours + ":" + minutes + amPM;
        var month = today.getMonth();
        var dateText = today.getDate() + " " + _app.getMonthNameEN(today.getMonth()) + " " + today.getFullYear();
        _app.setCurrentDate(timeText + " - " + dateText);
    }
    function restoreDefault() {
        isDirty = false;
        _app.restoreOriginalImage();
        isStamped = false;
        curAngleZ = 0;
        imageViewer.rotationZ = 0;
        curScaleX = 1.0;
        curScaleY = 1.0;
        brightnessSlider.value = 50;
        contrastSlider.value = 0;
        hideLightControl.play();
        lightControlShown = false;
        hideImageName.play();
        imageNameShown = false;
        restoreOriginalEffect.play();
    }
    function toggleLightControlBar() {
        if (lightControlShown) {
            hideLightControl.play();
        } else {
            showLightControl.play();
        }
        lightControlShown = ! lightControlShown;
    }
    function toggleImageName() {
        if (imageNameShown) {
            hideImageName.play();
        } else {
            showImageName.play();
        }
        imageNameShown = ! imageNameShown;
    }
    function startLoading() {
        startLoadingIndicator = true;
    }
    function stopLoading() {
        startLoadingIndicator = false;
    }
    function askBeforeClose() {
        if (isDirty) {
            closeImageScreenDialog.show();
        } else {
            closeImageScreen();
        }
    }
    function closeImageScreen() {
        restoreDefault();
        filterList.translationY = 350;
        filterIsShown = false;
        utilBar.translationY = 270;
        utilitiesIsShown = false;
        imageViewer.imageSource = "";
        nav.pop();
        _app.deleteTempImage();
    }

    function showTopToolBar() {
        topToolsBar.translationY = 0;
    }
    function hideTopToolBar() {
        topToolsBar.translationY = -130;
    }
    function alertMessage(msgTitle, msgContent) {
        alertDialog.dialogTitle = msgTitle;
        alertDialog.dialogContent = msgContent;
        alertDialog.open();
    }
    function saveAsNewPhoto() {
        _app.saveImageAs(imageSourceURL);
    }
    function saveChanges() {
        _app.saveImageChanges(imageSourceURL);
    }

    paneProperties: NavigationPaneProperties {
        backButton: ActionItem {
            title: "Close"
            onTriggered: {
                askBeforeClose();
            }
        }
    }
}
