import bb.cascades 1.0

Page {
    id: cropScreen
    property double scaleFactor: 1.0
    property string imageSourceURL: ""
    property real curScaleRatio: 1.0
    property real initialScale: 1.0
    property real curAngleZ: 0
    property bool isPinching: false
    property real cropWidth
    property real cropHeight
    property real startCropX
    property real startCropY
    property int curImageWidth
    property int curImageHeight
    Container {
        layout: DockLayout {
        }

        ImageView {
            imageSource: "asset:///images/1.png"
            scalingMethod: ScalingMethod.AspectFill
        }
        ScrollView {
            id: scrollImageView
            preferredWidth: 768
            preferredHeight: 768
            horizontalAlignment: HorizontalAlignment.Center
            verticalAlignment: VerticalAlignment.Top
            ImageView {
                id: imageViewerCrop
                objectName: "imageViewerCrop"
                scalingMethod: ScalingMethod.AspectFit
                scaleX: curScaleRatio
                scaleY: curScaleRatio
                attachedObjects: [
                    ImplicitAnimationController {
                        id: translationControllerY
                        propertyName: "translationY"
                    },
                    ImplicitAnimationController {
                        id: translationControllerX
                        propertyName: "translationX"
                    }
                ]
            }
        }
        ImageView {
            id: cropRect
            property real dy: 0
            property real dx: 0
            property real prevX: 0
            property real prevY: 0
            property int resizeYFingerZone: 40
            property real topCropPadding: 40
            property real bottomCropPadding: 768 - 40
            property real fingerYFrom: 0
            property real fingerYTo: 100
            imageSource: "asset:///images/cropFrame.png"
            scalingMethod: ScalingMethod.AspectFit
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Top
            onTouch: {
                if (isPinching) {
                    return;
                }

                // Checking for a press, then set the state variables we need.
                if (event.isDown()) {
                    cropRect.dx = event.localX;
                    cropRect.dy = event.localY;
                    console.log(dx + "x" + dy);
                } else if (event.isMove()) {
                    imageViewerCrop.translationX = cropRect.prevX + (event.localX - dx);
                    imageViewerCrop.translationY = cropRect.prevY + (event.localY - dy);
                    //console.log("Moving: " + imageViewerCrop.translationX + " | " + imageViewerCrop.translationY);
                } else if (event.isUp()) {
                    cropRect.prevX = imageViewerCrop.translationX;
                    cropRect.prevY = imageViewerCrop.translationY;
                    //console.log("Ended: " + imageViewerCrop.translationX + " | " + imageViewerCrop.translationY);
                }
            }
            gestureHandlers: [

                // Add a handler for pinch gestures
                PinchHandler {
                    // When the pinch gesture starts, save the initial scale of
                    // the image
                    onPinchStarted: {
                        isPinching = ! isPinching;
                        initialScale = imageViewerCrop.scaleX;
                    }

                    onPinchUpdated: {
                        curScaleRatio = initialScale + ((event.pinchRatio - 1) * scaleFactor);
                    }
                    onPinchEnded: {
                        if (imageViewerCrop.scaleX < 1.0) {
                            curScaleRatio = 1.0;
                        }
                        isPinching = ! isPinching;
                        console.log("curScaleRatio: " + curScaleRatio);
                    }
                }
            ]
        }
        Container {
            id: cropRectControl
            leftPadding: 10
            rightPadding: 10
            bottomPadding: 30
            verticalAlignment: VerticalAlignment.Bottom
            horizontalAlignment: HorizontalAlignment.Fill

            // Width Control
            Container {
                layout: DockLayout {}
                bottomMargin: 20
                horizontalAlignment: HorizontalAlignment.Fill
                verticalAlignment: VerticalAlignment.Center
                ImageView {
                    imageSource: "asset:///images/backgrounds/RoundedRectangle_Boder.png"
                    horizontalAlignment: HorizontalAlignment.Fill
                    verticalAlignment: VerticalAlignment.Center
                }
                Container {
                    leftPadding: 30
                    rightPadding: 30
                    layout: StackLayout {
                        orientation: LayoutOrientation.LeftToRight
                    }
                    verticalAlignment: VerticalAlignment.Center
                    Label {
                        text: "Width"
                        minWidth: 90
                        verticalAlignment: VerticalAlignment.Center
                        textStyle {
                            fontSizeValue: 6
                            fontSize: FontSize.PointValue
                            color: Color.create("#FAFAFA")
                        }
                        
                    }
                    Slider {
                        id: cropWidthControl
                        fromValue: 240
                        toValue: 768
                        value: 768
                        verticalAlignment: VerticalAlignment.Center
                        horizontalAlignment: HorizontalAlignment.Center
                        onValueChanged: {
                            cropRect.scaleX = cropWidthControl.value / 768;
                        }
                    }
                }
            }

            // Height control
            Container {
                layout: DockLayout {

                }
                horizontalAlignment: HorizontalAlignment.Fill
                verticalAlignment: VerticalAlignment.Center
                ImageView {
                    imageSource: "asset:///images/backgrounds/RoundedRectangle_Boder.png"
                    horizontalAlignment: HorizontalAlignment.Fill
                    verticalAlignment: VerticalAlignment.Center
                }
                Container {
                    layout: StackLayout {
                        orientation: LayoutOrientation.LeftToRight
                    }
                    leftPadding: 30
                    rightPadding: 30
                    verticalAlignment: VerticalAlignment.Center
                    horizontalAlignment: HorizontalAlignment.Fill
                    Label {
                        text: "Height"
                        
                        minWidth: 90
                        verticalAlignment: VerticalAlignment.Center
                        textStyle {
                            fontSize: FontSize.PointValue
                            fontSizeValue: 6
                            color: Color.create("#FAFAFA")
                        }
                    }
                    Slider {
                        id: cropHeightControl
                        fromValue: 240
                        toValue: 768
                        value: 768
                        
                        visible: true
                        verticalAlignment: VerticalAlignment.Center
                        horizontalAlignment: HorizontalAlignment.Fill
                        onValueChanged: {
                            cropRect.scaleY = cropHeightControl.value / 768;
                        }

                    }
                }
            }

        }
    }

    actions: [
        ActionItem {
            title: "Cancel"
            ActionBar.placement: ActionBarPlacement.OnBar
            imageSource: "asset:///images/icons/ic_cancel.png"
            onTriggered: {
                restoreDefault();
            }
        },
        ActionItem {
            title: "Crop"
            ActionBar.placement: ActionBarPlacement.OnBar
            imageSource: "asset:///images/icons/crop_icon.png"
            onTriggered: {
                _app.cropIt(imageSourceURL, curScaleRatio, imageViewerCrop.translationX, imageViewerCrop.translationY, cropRect.scaleX, cropRect.scaleY);
                restoreDefault();
            }
        }/*
        ActionItem {
            title: "BBM Avatar"
            imageSource: "asset:///images/icons/ic_edit_profile.png"
            ActionBar.placement: ActionBarPlacement.OnBar
            onTriggered: {
                _app.cropAndSetBBMAvatar(imageSourceURL, curScaleRatio, imageViewerCrop.translationX, imageViewerCrop.translationY, cropRect.scaleX, cropRect.scaleY);
                restoreDefault();
            }
        },*/
        
    ]
    function restoreDefault() {
        curScaleRatio = 1.0;
        initialScale = 1.0;
        curAngleZ = 0;
        cropRect.dx = 0;
        cropRect.dy = 0;
        cropRect.prevX = 0;
        cropRect.prevY = 0;
        imageViewerCrop.translationX = 0;
        imageViewerCrop.translationY = 0;
        OrientationSupport.supportedDisplayOrientation = SupportedDisplayOrientation.All;
        cropScreenSheet.close();
    }
}
