import bb.cascades 1.0

Container {
    layout: DockLayout {
    }
    ImageView {
        imageSource: "asset:///images/1.png"
        scalingMethod: ScalingMethod.AspectFill
    }
    Container {
        horizontalAlignment: HorizontalAlignment.Left
        verticalAlignment: VerticalAlignment.Top
        topPadding: 10
        leftPadding: 10
        ImageView {
            imageSource: "asset:///images/watermark_v3.png"
        }
        animations: [
            ScaleTransition {
                id: onTouchAnimationLogo
                fromX: 0.9
                fromY: 0.9
                toX: 1.0
                toY: 1.0
                duration: 500
                easingCurve: StockCurve.ElasticOut
            }
        ]
    }

    // Location Icon
    Container {
        horizontalAlignment: HorizontalAlignment.Right
        verticalAlignment: VerticalAlignment.Top
        topPadding: 10
        leftPadding: 10
        bottomPadding: 20
        ImageButton {
            id: locationIcon
            defaultImageSource: nav.locationStatusIcon
            animations: [
                FadeTransition {
                    id: fadeIn
                    duration: 1000
                    fromOpacity: 0.3
                    toOpacity: 1
                    onEnded: {
                        fadeOut.play();
                    }
                },
                FadeTransition {
                    id: fadeOut
                    duration: 1000
                    fromOpacity: 1
                    toOpacity: 0.3
                    onEnded: {
                        fadeIn.play();
                    }
                }
            ]
            onClicked: {
                _app.setupLocation();
            }
            onDefaultImageSourceChanged: {
                if (defaultImageSource != "asset:///images/icons/marker.png") {
                    opacity = 1;
                    fadeIn.stop();
                    fadeOut.stop()
                }
            }
        }
        animations: [
            ScaleTransition {
                id: onTouchAnimationLocationIcon
                fromX: 0.9
                fromY: 0.9
                toX: 1.0
                toY: 1.0
                duration: 500
                easingCurve: StockCurve.ElasticOut
            }
        ]
    }
    Container {
        horizontalAlignment: HorizontalAlignment.Center
        verticalAlignment: VerticalAlignment.Center
        Container {
            layout: StackLayout {
                orientation: LayoutOrientation.LeftToRight
            }
            HomeScreenMenuContainer {
                defaultImageSourceString: "asset:///images/Search_HomeScreen.png"
                onIsClicked: {
                    filePicker.open();
                }
            }
            HomeScreenMenuContainer {
                leftMargin: 10
                defaultImageSourceString: "asset:///images/Camera_HomeScreen.png"
                onIsClicked: {
                    _app.invokeCameraApp();
                }
            }
            animations: [
                TranslateTransition {
                    id: exit1
                    toX: -768
                    duration: 500
                }
            ]
            onCreationCompleted: {
                //moveRight1.play();
            }
        }
        Container {
            layout: StackLayout {
                orientation: LayoutOrientation.LeftToRight
            }
            topMargin: 10
            HomeScreenMenuContainer {
                defaultImageSourceString: "asset:///images/icons/ic_open.png"
                leftMargin: 10
                onIsClicked: {
                    _app.moreApps();
                }
            }
            HomeScreenMenuContainer {
                leftMargin: 10
                defaultImageSourceString: "asset:///images/Setting_HomeScreen.png"
                onIsClicked: {
                    settingsPageSheet.open();
                }
            }
            animations: [
                TranslateTransition {
                    id: exit2
                    toX: 768
                    duration: 500
                }
            ]
        }
        animations: [
            ScaleTransition {
                id: onTouchAnimation
                fromX: 0.9
                fromY: 0.9
                toX: 1.0
                toY: 1.0
                duration: 500
                easingCurve: StockCurve.ElasticOut
            }
        ]
    }
    Container {
        horizontalAlignment: HorizontalAlignment.Right
        verticalAlignment: VerticalAlignment.Bottom
        bottomPadding: 10
        rightPadding: 10
        layout: StackLayout {
            orientation: LayoutOrientation.LeftToRight
        }
        ImageButton {
            defaultImageSource: "asset:///images/icons/exit.png"
            preferredHeight: 128
            preferredWidth: 128
            onClicked: {
                exit1.play();
                exit2.play();
                exit4.play();
                goodbyeText.play();
            }
        }
        animations: [
            ScaleTransition {
                id: onTouchAnimationExit
                fromX: 0.9
                fromY: 0.9
                toX: 1.0
                toY: 1.0
                duration: 500
                easingCurve: StockCurve.ElasticOut
            }
        ]
    }
    ImageView {
        id: instruction1
        imageSource: "asset:///images/instruction_1.png"
        translationY: 290
        translationX: 20
        animations: [
            ScaleTransition {
                id: onTouchAnimationInstruct1
                fromX: 0.9
                fromY: 0.9
                toX: 1.0
                toY: 1.0
                duration: 500
                easingCurve: StockCurve.ElasticOut
            },
            TranslateTransition {
                id: exit4
                toX: -768
                duration: 500
            }
        ]
    }
    
    Label {
        translationX: 20
        translationY: -130
        text: "Thank you."
        multiline: true
        textStyle {
            fontSize: FontSize.PointValue
            fontSizeValue: 10
            color: Color.White
        }
        animations: [
            TranslateTransition {
                id: goodbyeText
                toY: 600
                duration: 1000
                onEnded: {
                    _app.exitApp();
                }
            }
        ]
    }
    onTouch: {
        if (event.isDown()) {
            onTouchAnimation.play();
            onTouchAnimationLogo.play();
            onTouchAnimationLocationIcon.play();
            onTouchAnimationInstruct1.play();
            onTouchAnimationExit.play();
        }
    }
    attachedObjects: [
        OrientationHandler {
            onOrientationAboutToChange: {
                if (orientation == UIOrientation.Landscape) {
                    //Changing the text and the paddings
                    instruction1.translationY = 40;
                    instruction1.translationX = 275;
                } else {
                    //Changing the text and the paddings
                    instruction1.translationY = 290;
                    instruction1.translationX = 20;
                }
            }
        }
    ]
    function stopFetchingLocation() {
        fadeIn.stop();
        fadeOut.stop();
        locationIcon.opacity = 1;
    }
    function startFetchingLocation() {
        fadeIn.play();
    }
}
