import bb.cascades 1.0

Container {
    signal tweetButtonClicked(string tweetText)
    property int charLeft: 80
    translationY: -1280
    background: Color.create("#474747")
    layout: DockLayout {
    }
    topPadding: 5
    leftPadding: 5
    rightPadding: 5
    bottomPadding: 5
    //verticalAlignment: VerticalAlignment.Fill
    ImageView {
        //imageSource: "asset:///images/background.png"
        horizontalAlignment: HorizontalAlignment.Fill
        verticalAlignment: VerticalAlignment.Fill
    }
    Container {
        id: tweetContainer
        background: Color.create("#272727")
        layout: StackLayout {
        }
        leftPadding: 20
        rightPadding: 20
        topPadding: 30
        horizontalAlignment: HorizontalAlignment.Fill
        verticalAlignment: VerticalAlignment.Fill
        Container {
            layout: StackLayout {
                orientation: LayoutOrientation.LeftToRight
            }
            ImageView {
                imageSource: "asset:///images/icons/twitter.png"
                verticalAlignment: VerticalAlignment.Center
            }
            Label {
                text: "Share Photo to Twitter"
                textStyle {
                    base: SystemDefaults.TextStyles.TitleText
                    color: Color.create("#FAFAFA")
                }
                verticalAlignment: VerticalAlignment.Center
            }
            horizontalAlignment: HorizontalAlignment.Center
            verticalAlignment: VerticalAlignment.Center
        }
        Divider {
        }
        TextArea {
            id: tweetContent
            preferredHeight: 250
            hintText: "80 characters"
            backgroundVisible: true
            onTextChanging: {
                charLeft = 80 - tweetContent.text.length;
                if (charLeft == 0) {
                    tweetContent.editable = false;
                } else {
                    tweetContent.editable = true;
                }
            }
        }
        Container {
            layout: StackLayout {
                orientation: LayoutOrientation.LeftToRight
            }
            leftPadding: 10
            background: Color.create("#474747")
            preferredHeight: 200
            ImageView {
                id: sharedImageThumb
                objectName: "sharedImageThumb"
                image: imageViewer.image
                //imageSource: "asset:///images/PhotoX_300.png"
                layoutProperties: StackLayoutProperties {
                    spaceQuota: 1
                }
                preferredHeight: 200
                preferredWidth: 200
                scalingMethod: ScalingMethod.AspectFit
            }
            Label {
                text: "Image will appear as a link."
                textStyle {
                    base: SystemDefaults.TextStyles.BodyText
                    color: Color.create("#FAFAFA")
                }
                layoutProperties: StackLayoutProperties {
                    spaceQuota: 3
                }
                verticalAlignment: VerticalAlignment.Center
            }
        }
        Container {
            layout: StackLayout {
                orientation: LayoutOrientation.RightToLeft
            }
            topPadding: 30
            bottomPadding: 10
            horizontalAlignment: HorizontalAlignment.Fill
            Button {
                id: tweetButton
                text: "Tweet"
                horizontalAlignment: HorizontalAlignment.Right
                preferredWidth: 100
                onClicked: {
                    tweetButtonClicked(tweetContent.text);
                    hideTweetPanel.play();
                }
            }
            Label {
                text: charLeft + ""
                layoutProperties: StackLayoutProperties {
                }
                textStyle {
                    base: SystemDefaults.TextStyles.BodyText
                    color: Color.create("#FAFAFA")
                }
                verticalAlignment: VerticalAlignment.Center
            }
        }
        Divider {
        }
        Container {
            layout: StackLayout {
                orientation: LayoutOrientation.LeftToRight
            }
            bottomPadding: 10
            Button {
                text: "Logout"
                visible: imageScreenPage.isConnectedToTwitter
                horizontalAlignment: HorizontalAlignment.Fill
                onClicked: {
                    hideTweetPanel.play();
                    _app.logoutTwitter();
                }
            }
            Button {
                text: "Cancel"
                horizontalAlignment: HorizontalAlignment.Fill
                onClicked: {
                    hideTweetPanel.play();
                }
            }
        }
    }
    animations: [
        TranslateTransition {
            id: showTweetPanel
            toY: 0
            duration: 900
            easingCurve: StockCurve.CubicOut
        },
        TranslateTransition {
            id: hideTweetPanel
            toY: -1280
            duration: 800
            easingCurve: StockCurve.CubicOut
            onEnded: {
            }
        }
    ]
    function show() {
        showTweetPanel.play();
    }
}
