// Default empty project template
import bb.cascades 1.0
import bb.cascades.pickers 1.0
import bb.system 1.0

NavigationPane {
    id: nav
    property string curSelectedPhotoURL: ""
    property string locationStatusIcon: "asset:///images/icons/marker.png"
    property string defaultPhotoFolder: "/accounts/1000/shared"
    
    // Top Menu
    Menu.definition: MenuDefinition {
        // Add a Help action
        helpAction: HelpActionItem {
            onTriggered: {
                helpSheet.open();
            }
        }

        // Add a Settings action
        settingsAction: SettingsActionItem {
            onTriggered: {
                settingsPageSheet.open();
            }
        }

        // Add any remaining actions
        actions: [
            ActionItem {
                title: "About"
                imageSource: "asset:///images/icons/ic_info.png"
                onTriggered: {
                    nav.push(aboutScreen);
                    aboutScreen.animateThis();
                }
            }
        ]
    }

    Page {
        HomeScreen {
            id: homeScreenPage
        }
    }

    attachedObjects: [
        FilePicker {
            id: filePicker
            objectName: "filePicker"
            //type: FileType.Picture // Doesn't work
            //defaultType: FileType.Picture // Doesn't work
            title: "Select Photo"
            //viewMode: FilePickerViewMode.GridView // Doesn't work
            directories: [ defaultPhotoFolder ]
            onFileSelected: {
                logToConsole("FileSelected signal received : " + selectedFiles[0]);
                curSelectedPhotoURL = selectedFiles[0];
                imageScreenPage.startLoadingIndicator = true;
                _app.showImageScreen(curSelectedPhotoURL);
                filePicker.directories = [ curSelectedPhotoURL.substring(0, curSelectedPhotoURL.lastIndexOf("/")) ];
            }
        },

        FilePicker {
            id: folderPicker
            objectName: "folderPicker"
            mode: FilePickerMode.SaverMultiple
            //type: FileType.Picture // Doesn't work
            //defaultType: FileType.Picture // Doesn't work
            title: "Select Folder"
            //viewMode: FilePickerViewMode.GridView // Doesn't work
            directories: [ "/accounts/1000/shared" ]
            onFileSelected: {
                logToConsole("FileSelected signal received : " + selectedFiles[0]);
                if (selectedFiles && selectedFiles.length > 0) {
                    settingsPage.defaultFolder = selectedFiles[0];
                    nav.defaultPhotoFolder = selectedFiles[0];
                    _app.saveSetting("DEFAULT_FOLDER", selectedFiles[0]);
                }
            }
        },
        ImageScreen {
            id: imageScreenPage
            objectName: "imageScreenPage"
        },
        Policy {
            id: tosDialog
            objectName: "tosDialog"
        },
        Sheet {
            id: settingsPageSheet
            SettingsPage {
                id: settingsPage
                objectName: "settingsPage"
            }
        },
        AboutScreen {
            id: aboutScreen
        },
        Sheet {
            id: helpSheet
            HelpScreen {
                id: helpScreen
            }
        },
        SystemDialog {
            id: confirmDeleteDialog
            title: "Delete"
            body: "The current photo will be removed permanently and this action can't be undone. Continue?"
            onFinished: {
                if (confirmDeleteDialog.result == SystemUiResult.CancelButtonSelection) {
                    _app.logToConsole("Cancel");

                } else if (confirmDeleteDialog.result == SystemUiResult.ConfirmButtonSelection) {
                    _app.logToConsole("Confirm");
                    imageScreenPage.deleteCurPhoto();
                }
            }
        },
        SystemDialog {
            id: confirmExportPDFDialog
            title: "Export to PDF"
            body: "The PDF file will be saved in the same folder as this photo. Continue?"
            onFinished: {
                if (confirmExportPDFDialog.result == SystemUiResult.CancelButtonSelection) {
                    _app.logToConsole("Cancel");
                } else if (confirmExportPDFDialog.result == SystemUiResult.ConfirmButtonSelection) {
                    _app.logToConsole("Confirm");
                    imageScreenPage.exportToPDF();
                }
            }
        },
        SystemDialog {
            id: confirmSetWallpaper
            title: "Wallpaper"
            body: "Current photo will be set as wallpaper. Continue?"
            onFinished: {
                if (confirmSetWallpaper.result == SystemUiResult.CancelButtonSelection) {
                    _app.logToConsole("Cancel");
                } else if (confirmSetWallpaper.result == SystemUiResult.ConfirmButtonSelection) {
                    _app.logToConsole("Confirm");
                    imageScreenPage.setCurPhotoAsWallpaper();
                }
            }
        },
        SystemDialog {
            id: confirmRestoreOriginal
            title: "Restore to original"
            body: "All the changes to photo will be lost and can't be undone. Continue?"
            onFinished: {
                if (confirmRestoreOriginal.result == SystemUiResult.CancelButtonSelection) {
                    _app.logToConsole("Cancel");
                } else if (confirmRestoreOriginal.result == SystemUiResult.ConfirmButtonSelection) {
                    _app.logToConsole("Confirm");
                    imageScreenPage.restoreDefault();
                }
            }
        },
        SystemDialog {
            id: closeImageScreenDialog
            title: "Dialog"
            body: "Do you want to save changes to the photo?"
            buttons: [
                SystemUiButton {
                    id: saveDialogButton
                    label: "Save"
                    enabled: true
                },
                SystemUiButton {
                    id: saveAsDialogButton
                    label: "Save As New"
                    enabled: true
                }
            ]
            
            onFinished: {
                if (closeImageScreenDialog.result == SystemUiResult.CancelButtonSelection) {
                    _app.logToConsole("Discard Changes");
                    imageScreenPage.closeImageScreen();
                } else if (closeImageScreenDialog.result == SystemUiResult.ConfirmButtonSelection) {
                    _app.logToConsole("CancelButtonSelection");
                }
                if (closeImageScreenDialog.buttonSelection() == saveAsDialogButton) {
                    _app.logToConsole("Save As New");
                    imageScreenPage.saveAsNewPhoto();
                    imageScreenPage.closeImageScreen();
                }
                if (closeImageScreenDialog.buttonSelection() == saveDialogButton) {
                    _app.logToConsole("ConfirmButtonSelection");
                    imageScreenPage.saveChanges();
                    imageScreenPage.closeImageScreen();
                }
            }
        },
        // ActiveFrameCover
        ActiveFrameCover {
            id: activeFrameCover
            objectName: "activeFrameCover"
        }
    ]
    onCreationCompleted: {
        closeImageScreenDialog.cancelButton.label = "Discard Changes";
        closeImageScreenDialog.confirmButton.label = "Cancel";
    }
    function logToConsole(message) {
        _app.logToConsole(message);
    }
    function stopFetchingLocation() {
        homeScreenPage.stopFetchingLocation();
    }
    function startFetchingLocation() {
        homeScreenPage.startFetchingLocation();
    }
}
